==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/MeetingInfo.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "allowConversationWithoutHost"})
@JsonInclude(Include.NON_NULL)
public class MeetingInfo implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("allowConversationWithoutHost")
    protected Boolean allowConversationWithoutHost;

    protected MeetingInfo() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.meetingInfo";
    }

    @Property(name="allowConversationWithoutHost")
    @JsonIgnore
    public Optional<Boolean> getAllowConversationWithoutHost() {
        return Optional.ofNullable(allowConversationWithoutHost);
    }

    public MeetingInfo withAllowConversationWithoutHost(Boolean allowConversationWithoutHost) {
        MeetingInfo _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.meetingInfo");
        _x.allowConversationWithoutHost = allowConversationWithoutHost;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    private MeetingInfo _copy() {
        MeetingInfo _x = new MeetingInfo();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.allowConversationWithoutHost = allowConversationWithoutHost;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MeetingInfo[");
        b.append("allowConversationWithoutHost=");
        b.append(this.allowConversationWithoutHost);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/MeetingInfo.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "allowConversationWithoutHost"})
@JsonInclude(Include.NON_NULL)
public class MeetingInfo implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("allowConversationWithoutHost")
    protected Boolean allowConversationWithoutHost;

    protected MeetingInfo() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.meetingInfo";
    }

    @Property(name="allowConversationWithoutHost")
    @JsonIgnore
    public Optional<Boolean> getAllowConversationWithoutHost() {
        return Optional.ofNullable(allowConversationWithoutHost);
    }

    public MeetingInfo withAllowConversationWithoutHost(Boolean allowConversationWithoutHost) {
        MeetingInfo _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.meetingInfo");
        _x.allowConversationWithoutHost = allowConversationWithoutHost;
        return _x;
    }

    public MeetingInfo withUnmappedField(String name, Object value) {
        MeetingInfo _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    private MeetingInfo _copy() {
        MeetingInfo _x = new MeetingInfo();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.allowConversationWithoutHost = allowConversationWithoutHost;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MeetingInfo[");
        b.append("allowConversationWithoutHost=");
        b.append(this.allowConversationWithoutHost);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
